prijsoog package
================

Subpackages
-----------

.. toctree::

    prijsoog.supermarkets

Module contents
---------------

.. automodule:: prijsoog
    :members:
    :undoc-members:
    :show-inheritance:
